@@ -7,14 +7,11 @@ test_that(desc="api_parameters()",{
     "http://api.scb.se/OV0104/v1/doris/sv/ssd/BE/BE0101/BE0101A/BefolkningNy"
   )
   
-  expect_that({
-    api_all_conf <- api_parameters()}, 
-    not(throws_error()))
+  expect_warning(api_all_conf <- api_parameters())
   
   for (test in api_tests_utils_api_parameters){
-    expect_that({
-      api_url_conf <- api_parameters(test)}, 
-      not(throws_error()),
+    expect_warning(
+      api_url_conf <- api_parameters(test),
       info = test)
   }
 })
